@@ -1699,6 +1699,20 @@ def eol_mime():
     raise svntest.Failure
 
 
+def check_props(allprops, fname, keywords, eol_style, mime_type):
+  "helper function for keywords test"
+  props = allprops[fname]
+  if (keywords == props.get('svn:keywords') and
+      eol_style == props.get('svn:eol-style') and
+      mime_type == props.get('svn:mime-type') ):
+    pass
+  else:
+    print "Unexpected properties for '%s'" % fname
+    print "keywords:\t%s\t%s" % (keywords, props.get('svn:keywords'))
+    print "eol-style:\t%s\t%s" % (eol_style, props.get('svn:eol-style'))
+    print "mime-type:\t%s\t%s" % (mime_type, props.get('svn:mime-type'))
+    raise svntest.Failure
+
 def keywords():
   "test setting of svn:keywords property among others"
   repos, wc, logs = ensure_conversion('keywords')
@@ -1713,54 +1727,14 @@ def keywords():
     'foo.kv'      : props_for_path(wc_tree, '/trunk/foo.kv'),
     }
 
-  if allprops['foo.default'].get('svn:keywords') != 'author date id revision':
-    raise svntest.Failure
-  if allprops['foo.default'].get('svn:eol-style') != 'native':
-    raise svntest.Failure
-  if allprops['foo.default'].get('svn:mime-type') is not None:
-    raise svntest.Failure
-  
-  if allprops['foo.kkvl'].get('svn:keywords') != 'author date id revision':
-    raise svntest.Failure
-  if allprops['foo.kkvl'].get('svn:eol-style') != 'native':
-    raise svntest.Failure
-  if allprops['foo.kkvl'].get('svn:mime-type') is not None:
-    raise svntest.Failure
-  
-  if allprops['foo.kkv'].get('svn:keywords') != 'author date id revision':
-    raise svntest.Failure
-  if allprops['foo.kkv'].get('svn:eol-style') != 'native':
-    raise svntest.Failure
-  if allprops['foo.kkv'].get('svn:mime-type') is not None:
-    raise svntest.Failure
-  
-  if allprops['foo.kb'].get('svn:keywords') is not None:
-    raise svntest.Failure
-  if allprops['foo.kb'].get('svn:eol-style') is not None:
-    raise svntest.Failure
-  if allprops['foo.kb'].get('svn:mime-type') != 'application/octet-stream':
-    raise svntest.Failure
-  
-  if allprops['foo.kk'].get('svn:keywords') is not None:
-    raise svntest.Failure
-  if allprops['foo.kk'].get('svn:eol-style') != 'native':
-    raise svntest.Failure
-  if allprops['foo.kk'].get('svn:mime-type') is not None:
-    raise svntest.Failure
-  
-  if allprops['foo.ko'].get('svn:keywords') is not None:
-    raise svntest.Failure
-  if allprops['foo.ko'].get('svn:eol-style') != 'native':
-    raise svntest.Failure
-  if allprops['foo.default'].get('svn:mime-type') is not None:
-    raise svntest.Failure
-  
-  if allprops['foo.kv'].get('svn:keywords') is not None:
-    raise svntest.Failure
-  if allprops['foo.kv'].get('svn:eol-style') != 'native':
-    raise svntest.Failure
-  if allprops['foo.kv'].get('svn:mime-type') is not None:
-    raise svntest.Failure
+  check_props(allprops, 'foo.default', 'Author Date Id Revision', 'native',
+      None)
+  check_props(allprops, 'foo.kkvl', 'Author Date Id Revision', 'native', None)
+  check_props(allprops, 'foo.kkv', 'Author Date Id Revision', 'native', None)
+  check_props(allprops, 'foo.kb', None, None, 'application/octet-stream')
+  check_props(allprops, 'foo.kk', None, 'native', None)
+  check_props(allprops, 'foo.ko', None, 'native', None)
+  check_props(allprops, 'foo.kv', None, 'native', None)
 
 
 def ignore():
@@ -1826,6 +1800,24 @@ def vendor_branch_delete_add():
   # This will error if the bug is present
   repos, wc, logs = ensure_conversion('vendor-branch-delete-add')
 
+def resync_pass2_ordering_bug():
+  "reveal a bug that resyncs timestamps in pass2"
+  repos, wc, logs = ensure_conversion('resync-pass2-ordering')
+  # If the conversion succeeds, then we're okay.  We could check the
+  # actual revisions, too, but the main thing is to know that the
+  # conversion doesn't fail.
+
+def native_eol():
+  "only LFs for svn:eol-style=native files"
+  repos, wc, logs = ensure_conversion('native-eol', None, None)
+  lines = run_program(svntest.main.svnadmin_binary, None, 'dump', '-q', repos)
+  # Verify that all files in the dump have LF EOLs.  We're actually
+  # testing the whole dump file, but the dump file itself only uses
+  # LF EOLs, so we're safe.
+  for line in lines:
+    if line[-1] != '\n' or line[:-1].find('\r') != -1:
+      raise svntest.Failure
+
 
 #----------------------------------------------------------------------
 
@@ -1834,7 +1826,7 @@ def vendor_branch_delete_add():
 
 # list all tests here, starting with None:
 test_list = [ None,
-              show_usage,
+              show_usage,                           # 1
               attr_exec,
               space_fname,
               two_quick,
@@ -1843,7 +1835,7 @@ test_list = [ None,
               simple_commits,
               simple_tags,
               simple_branch_commits,
-              mixed_time_tag,
+              mixed_time_tag,                       # 10
               mixed_time_branch_with_added_file,
               mixed_commit,
               split_time_branch,
@@ -1853,7 +1845,7 @@ test_list = [ None,
               ctrl_char_in_log,
               overdead,
               no_trunk_prune,
-              double_delete,
+              double_delete,                        # 20
               split_branch,
               resync_misgroups,
               tagged_branch_and_trunk,
@@ -1863,7 +1855,7 @@ test_list = [ None,
               nonascii_filenames,
               vendor_branch_sameness,
               default_branches,
-              compose_tag_three_sources,
+              compose_tag_three_sources,            # 30
               pass5_when_to_fill,
               peer_path_pruning,
               empty_trunk,
@@ -1873,7 +1865,7 @@ test_list = [ None,
               resync_bug,
               branch_from_default_branch,
               file_in_attic_too,
-              symbolic_name_filling_guide,
+              symbolic_name_filling_guide,          # 40
               eol_mime,
               keywords,
               ignore,
@@ -1882,6 +1874,8 @@ test_list = [ None,
               XFail(revision_reorder_bug),
               exclude,
               vendor_branch_delete_add,
+              XFail(resync_pass2_ordering_bug),
+              native_eol,                           # 50
              ]
 
 if __name__ == '__main__':
